@@ -35,6 +35,7 @@ class DynamicSetting(object):
                  download_options=None,
                  debug_version=DEFAULT_DEBUG_VERSION,
                  fallback_allowed=False,
+                 health_relevant=True,
                  download_timeout=1.5,
                  verbose=False):
 
@@ -45,6 +46,7 @@ class DynamicSetting(object):
         self.load_time = None
         self.source = None
         self.fallback_allowed = fallback_allowed
+        self.health_relevant = health_relevant
         self.verbose = verbose
 
         self.domain = domain
@@ -90,6 +92,7 @@ class DynamicSetting(object):
                    download_subkey=obj.get('subkey'),
                    version_subkey=obj.get('version'),
                    fallback_allowed=obj.get('fallback_allowed', False),
+                   health_relevant=obj.get('health_relevant', True),
                    download_timeout=obj.get('download_timeout', 1.5),
                    verbose=verbose)
 
@@ -533,7 +536,8 @@ class DynamicSetting(object):
             'allow_fallback': self.fallback_allowed,
             'fallback': self.is_fallback,
             'source': self.source,
-            'version': self.version
+            'version': self.version,
+            'health_relevant': self.health_relevant
         }
         if not healthy:
             d.update({'reason': reason})
